==> nougat-0.2.0-py3-none-any.whl: nougat/app.py <==
import logging
from functools import partial
from nougat.exceptions import *
from nougat.utils import is_middleware, response_format
from nougat.config import Config

from typing import List, Tuple, TypeVar, Type, Set, Union, Callable
from nougat.context import Request, Response
from nougat.routing import Routing, Route, Router

from nougat.guarder import GuarderManager

import curio
import signal
from nougat.http_wrapper import HTTPWrapper


RoutingType = TypeVar('RoutingType', bound=Routing)


class Nougat(object):

    def __init__(self, name='Nougat APP') -> None:

        self.name = name
        self.router: 'Router' = Router()

        self.config = Config()
        self.__middleware_chain = []

        self.sections = {}

        self.guarder = GuarderManager()  # Guarder Manager
        self.guarder.guard(self, 'app')

        self.debug: bool = False

        # new version
        self.__routes: Set[Tuple('Routing', 'Route')] = set()

    def use(self, middleware):
        """
        Register Middleware
        :param middleware: The Middleware Function
        """

        is_middleware(middleware)
        middleware = middleware
        self.__middleware_chain.append(middleware)

    def guarders(self, guarders: Union[List[Callable], Callable]):
        """
        Register Guarder function
        :param guarders: The Guarder Function
        """

        if not isinstance(guarders, list):
            guarders = [guarders]

        for guarder in guarders:
            # TODO: check redefinition
            self.guarder.guard(guarder)

    async def handler(self, request: 'Request'):
        """
        The handler handling each request
        :param request: the Request instance
        :return: The Response instance
        """

        response = Response()

        try:

            # match the Routing and Route from Router
            routing_class, route = self.router.match(request.method, request.url.path)
            routing = routing_class(request, response)

            # Guarder Processes
            with self.guarder.guard_context(routing):
                controller = await self.guarder.generator(route.controller)

            # Handling Middleware
            handler = partial(controller, routing)

            chain_reverse = self.__middleware_chain[::-1]
            for middleware in chain_reverse:
                handler = partial(middleware, context=routing, next=handler)

            controller_res = await handler()

            # Formatting the Response data
            res_type, controller_res = response_format(controller_res)

        except ResponseContentCouldNotFormat:
            res_type = 'text/plain'
            controller_res = "unable to format response"

        except RouteNoMatchException:
            response.status = 404
            res_type = 'text/plain'
            controller_res = None

        response.type = res_type
        response.res = controller_res

        return response

    def run(self, host: str="localhost", port: int=8000, debug: bool=False):
        """
        start the http server
        :param host: The listening host
        :param port: The listening port
        :param debug: whether it is in debug mod or not
        :return:
        """
        if debug:
            print("Nougat is listening on http://{}:{}\n".format(host, port))
        self.debug = debug
        curio.run(self.start_server, host, port)

    def doc(self):
        """
        generate the api document
        :return: the json of api structure
        """
        return {
            'name': self.name,
            'sections': [section.doc() for _, section in self.sections.items()]
        }

    def route(self, routing: Type[RoutingType]):
        """
        Register Routing class
        :param routing: Routing Class, not its instance
        :return:
        """
        logging.info('adding Routing {}'.format(routing.__class__))

        routing_prefix = routing.prefix

        for route in routing.routes():
            route.set_prefix(routing_prefix)
            self.router.add_routing(routing, route)

    async def start_server(self, host: str, port: int):

        async with curio.SignalQueue(signal.SIGINT, signal.SIGTERM) as sig_queue:

            server = await curio.spawn(curio.tcp_server, host, port, self.http_serve)

            await sig_queue.get()  # waiting for signal

            print("preparing shutdown server")
            await server.cancel()

    async def http_serve(self, sock, address):
        """
        the income function of curio.tcp_server
        """
        await HTTPWrapper(sock, address).process(self)

==> nougat-0.2.1-py3-none-any.whl: nougat/app.py <==
import logging
from functools import partial
from nougat.exceptions import *
from nougat.utils import is_middleware, controller_result_to_response
from nougat.config import Config

from typing import List, Tuple, TypeVar, Type, Set, Union, Callable
from nougat.context import Request, Response
from nougat.routing import Routing, Route, Router

from nougat.http_wrapper import HTTPWrapper
import asyncio


RoutingType = TypeVar('RoutingType', bound=Routing)


class Nougat(object):

    def __init__(self, name='Nougat APP') -> None:

        self.name = name
        self.router: 'Router' = Router()

        self.config = Config()
        self.__middleware_chain = []

        self.sections = {}


        self.debug: bool = False

        # new version
        self.__routes: Set[Tuple('Routing', 'Route')] = set()

    def use(self, middleware):
        """
        Register Middleware
        :param middleware: The Middleware Function
        """

        is_middleware(middleware)
        middleware = middleware
        self.__middleware_chain.append(middleware)

    async def handler(self, request: 'Request'):
        """
        The handler handling each request
        :param request: the Request instance
        :return: The Response instance
        """

        response = Response()

        try:

            # match the Routing and Route from Router
            routing_class, route, url_dict = self.router.match(request.method, request.url.path)
            request.url_dict = url_dict
            routing = routing_class(self, request, response, route)

            # Handling Middleware
            handler = partial(route.controller, routing)

            # save the return value to response.res
            handler = partial(controller_result_to_response, context=routing, next=handler)  # save the result to response res

            # Routing Time
            handler = partial(routing.handler, route=route, controller=handler)

            # Global Middleware
            chain_reverse = self.__middleware_chain[::-1]
            for middleware in chain_reverse:
                handler = partial(middleware, context=routing, next=handler)

            await handler()

            # Formatting the Response data

        except ResponseContentCouldNotFormat:
            response.type = 'text/plain'
            response.res = "unable to format response"

        except RouteNoMatchException:
            response.status = 404
            response.type = 'text/plain'
            response.res = None

        except HttpException as e:
            response.status = e.status
            response.res = e.body

        return response

    def run(self, host: str="localhost", port: int=8000, debug: bool=False):
        """
        start the http server
        :param host: The listening host
        :param port: The listening port
        :param debug: whether it is in debug mod or not
        :return:
        """
        if debug:
            print("Nougat is listening on http://{}:{}\n".format(host, port))
        self.debug = debug
        loop = asyncio.new_event_loop()
        loop.run_until_complete(self.start_server(host, port))
        try:
            loop.run_forever()
        except KeyboardInterrupt:
            loop.close()

    def doc(self):
        """
        generate the api document
        :return: the json of api structure
        """
        return {
            'name': self.name,
            'sections': [section.doc() for _, section in self.sections.items()]
        }

    def route(self, routing: Type[RoutingType]):
        """
        Register Routing class
        :param routing: Routing Class, not its instance
        :return:
        """
        logging.info('adding Routing {}'.format(routing.__class__))

        routing_prefix = routing.prefix

        for route in routing.routes():
            route.set_prefix(routing_prefix)
            self.router.add_routing(routing, route)

    async def start_server(self, host: str, port: int):

        return await asyncio.start_server(self.http_serve, host, port)

    async def http_serve(self, reader, writer):
        """
        the income function of curio.tcp_server
        """
        address = writer.get_extra_info('peername')
        await HTTPWrapper((reader, writer), address).process(self)
